@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # The internetarchive module is a Python/CLI interface to Archive.org.
 #
@@ -34,23 +33,31 @@ Usage::
 :license: AGPL 3, see LICENSE for more details.
 """
 
-from __future__ import absolute_import
-
 __title__ = 'internetarchive'
-__version__ = '1.9.9'
 __author__ = 'Jacob M. Johnson'
 __license__ = 'AGPL 3'
 __copyright__ = 'Copyright (C) 2012-2019 Internet Archive'
 
-from internetarchive.item import Item
-from internetarchive.files import File
-from internetarchive.search import Search
+from .__version__ import __version__  # isort:skip
+from internetarchive.api import (
+    configure,
+    delete,
+    download,
+    get_files,
+    get_item,
+    get_session,
+    get_tasks,
+    get_user_info,
+    get_username,
+    modify_metadata,
+    search_items,
+    upload,
+)
 from internetarchive.catalog import Catalog
+from internetarchive.files import File
+from internetarchive.item import Item
+from internetarchive.search import Search
 from internetarchive.session import ArchiveSession
-from internetarchive.api import get_item, get_files, modify_metadata, upload, \
-    download, delete, get_tasks, search_items, get_session, configure, get_username, \
-    get_user_info
-
 
 __all__ = [
     '__version__',
@@ -79,13 +86,6 @@ __all__ = [
 
 # Set default logging handler to avoid "No handler found" warnings.
 import logging
-try:  # Python 2.7+
-    from logging import NullHandler
-except ImportError:
-    class NullHandler(logging.Handler):
-        def emit(self, record):
-            pass
-
 
 log = logging.getLogger(__name__)
-log.addHandler(NullHandler())
+log.addHandler(logging.NullHandler())
