@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # The internetarchive module is a Python/CLI interface to Archive.org.
 #
@@ -26,13 +25,16 @@ This module contains the Archive.org authentication handlers for Requests.
 :copyright: (C) 2012-2019 by Internet Archive.
 :license: AGPL 3, see LICENSE for more details.
 """
+from __future__ import annotations
+
 from requests.auth import AuthBase
+
 from internetarchive.exceptions import AuthenticationError
 
 
 class S3Auth(AuthBase):
     """Attaches S3 Basic Authentication to the given Request object."""
-    def __init__(self, access_key=None, secret_key=None):
+    def __init__(self, access_key: str | None = None, secret_key: str | None = None):
         self.access_key = access_key
         self.secret_key = secret_key
 
@@ -49,19 +51,19 @@ class S3Auth(AuthBase):
                 raise AuthenticationError('No access_key or secret_key set!'
                                           ' Have you run `ia configure`?')
 
-        auth_str = 'LOW {a}:{s}'.format(a=self.access_key, s=self.secret_key)
+        auth_str = f'LOW {self.access_key}:{self.secret_key}'
         r.headers['Authorization'] = auth_str
         return r
 
 
 class S3PostAuth(AuthBase):
     """Attaches S3 Basic Authentication to the given Request object."""
-    def __init__(self, access_key=None, secret_key=None):
+    def __init__(self, access_key: str | None = None, secret_key: str | None = None):
         self.access_key = access_key
         self.secret_key = secret_key
 
     def __call__(self, r):
-        auth_str = '&access={a}&secret={s}'.format(a=self.access_key, s=self.secret_key)
+        auth_str = f'&access={self.access_key}&secret={self.secret_key}'
         if not r.body:
             r.body = ''
         r.body += auth_str
