@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # The internetarchive module is a Python/CLI interface to Archive.org.
 #
@@ -35,17 +34,18 @@ options:
     -n, --netrc                Use netrc file for login.
     -c, --print-cookies        Print archive.org logged-in-* cookies.
 """
-from __future__ import absolute_import, print_function, unicode_literals
-import sys
+from __future__ import annotations
+
 import netrc
+import sys
 
 from docopt import docopt
 
-from internetarchive import configure
+from internetarchive import ArchiveSession, configure
 from internetarchive.exceptions import AuthenticationError
 
 
-def main(argv, session):
+def main(argv: list[str], session: ArchiveSession) -> None:
     args = docopt(__doc__, argv=argv)
     if args['--print-cookies']:
         user = session.config.get('cookies', {}).get('logged-in-user')
@@ -61,38 +61,39 @@ def main(argv, session):
                 print('error: "logged-in-sig" cookie not found in config file, '
                       'try reconfiguring.', file=sys.stderr)
             sys.exit(1)
-        print('logged-in-user={}; logged-in-sig={}'.format(user, sig))
+        print(f'logged-in-user={user}; logged-in-sig={sig}')
         sys.exit()
     try:
         # CLI params.
         if args['--username'] and args['--password']:
             config_file_path = configure(args['--username'],
                                          args['--password'],
+                                         config_file=session.config_file,
                                          host=session.host)
-            print('Config saved to: {0}'.format(config_file_path))
+            print(f'Config saved to: {config_file_path}', file=sys.stderr)
 
         # Netrc
         elif args['--netrc']:
-            print("Configuring 'ia' with netrc file...")
+            print("Configuring 'ia' with netrc file...", file=sys.stderr)
             try:
                 n = netrc.netrc()
             except netrc.NetrcParseError as exc:
-                print('error: netrc.netrc() cannot parse your .netrc file.')
+                print('error: netrc.netrc() cannot parse your .netrc file.', file=sys.stderr)
                 sys.exit(1)
             username, _, password = n.hosts['archive.org']
             config_file_path = configure(username,
-                                         password,
+                                         password or "",
                                          config_file=session.config_file,
                                          host=session.host)
-            print('Config saved to: {0}'.format(config_file_path))
+            print(f'Config saved to: {config_file_path}', file=sys.stderr)
 
         # Interactive input.
         else:
             print("Enter your Archive.org credentials below to configure 'ia'.\n")
             config_file_path = configure(config_file=session.config_file,
                                          host=session.host)
-            print('\nConfig saved to: {0}'.format(config_file_path))
+            print(f'\nConfig saved to: {config_file_path}')
 
     except AuthenticationError as exc:
-        print('\nerror: {0}'.format(str(exc)))
+        print(f'\nerror: {exc}', file=sys.stderr)
         sys.exit(1)
