@@ -1,8 +1,7 @@
-# -*- coding: utf-8 -*-
 #
 # The internetarchive module is a Python/CLI interface to Archive.org.
 #
-# Copyright (C) 2012-2019 Internet Archive
+# Copyright (C) 2012-2021 Internet Archive
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as
@@ -28,6 +27,8 @@ usage:
     ia metadata <identifier>... [--append=<key:value>... | --append-list=<key:value>...]
                                 [--priority=<priority>] [--target=<target>]
                                 [--header=<key:value>...]
+    ia metadata <identifier>... --insert=<key:value>... [--priority=<priority>]
+                                [--target=<target>] [--header=<key:value>...]
     ia metadata --spreadsheet=<metadata.csv> [--priority=<priority>]
                 [--modify=<key:value>...] [--header=<key:value>...]
     ia metadata --help
@@ -39,6 +40,8 @@ options:
     -t, --target=<target>               The metadata target to modify.
     -a, --append=<key:value>...         Append a string to a metadata element.
     -A, --append-list=<key:value>...    Append a field to a metadata element.
+    -i, --insert=<key:value>...      Insert a value into a multi-value field given
+                                        an index (e.g. `--insert=collection[0]:foo`).
     -s, --spreadsheet=<metadata.csv>    Modify metadata in bulk using a spreadsheet as
                                         input.
     -e, --exists                        Check if an item exists
@@ -48,84 +51,87 @@ options:
                                         Works on both single and multi-field metadata
                                         elements.
 """
-from __future__ import absolute_import, unicode_literals, print_function
-import sys
+from __future__ import annotations
+
+import csv
 import os
-try:
-    import ujson as json
-except ImportError:
-    import json
-import io
+import sys
 from collections import defaultdict
 from copy import copy
+from typing import Mapping
 
 from docopt import docopt, printable_usage
-from schema import Schema, SchemaError, Or, And, Use
-import six
+from requests import Response
+from schema import And, Or, Schema, SchemaError, Use  # type: ignore[import]
 
-from internetarchive.cli.argparser import get_args_dict, get_args_dict_many_write,\
-    get_args_header_dict
+from internetarchive import item, session
+from internetarchive.cli.argparser import (
+    get_args_dict,
+    get_args_dict_many_write,
+    get_args_header_dict,
+)
 from internetarchive.exceptions import ItemLocateError
-
-# Only import backports.csv for Python2 (in support of FreeBSD port).
-PY2 = sys.version_info[0] == 2
-if sys.version_info[0] == 2:
-    from backports import csv
-else:
-    import csv
+from internetarchive.utils import json
 
 
-def modify_metadata(item, metadata, args):
-    append = True if args['--append'] else False
-    append_list = True if args['--append-list'] else False
+def modify_metadata(item: item.Item, metadata: Mapping, args: Mapping) -> Response:
+    append = bool(args['--append'])
+    append_list = bool(args['--append-list'])
+    insert = bool(args['--insert'])
     try:
         r = item.modify_metadata(metadata, target=args['--target'], append=append,
                                  priority=args['--priority'], append_list=append_list,
-                                 headers=args['--header'])
+                                 headers=args['--header'], insert=insert)
+        assert isinstance(r, Response)  # mypy: modify_metadata() -> Request | Response
     except ItemLocateError as exc:
-        print('{} - error: {}'.format(item.identifier, str(exc)), file=sys.stderr)
+        print(f'{item.identifier} - error: {exc}', file=sys.stderr)
         sys.exit(1)
     if not r.json()['success']:
         error_msg = r.json()['error']
-        if 'no changes' in r.content.decode('utf-8'):
-            etype = 'warning'
-        else:
-            etype = 'error'
-        print('{0} - {1} ({2}): {3}'.format(
-            item.identifier, etype, r.status_code, error_msg), file=sys.stderr)
+        etype = 'warning' if 'no changes' in r.text else 'error'
+        print(f'{item.identifier} - {etype} ({r.status_code}): {error_msg}', file=sys.stderr)
         return r
-    print('{0} - success: {1}'.format(item.identifier, r.json()['log']))
+    print(f'{item.identifier} - success: {r.json()["log"]}', file=sys.stderr)
     return r
 
 
-def remove_metadata(item, metadata, args):
-    md = defaultdict(list)
+def remove_metadata(item: item.Item, metadata: Mapping, args: Mapping) -> Response:
+    md: dict[str, list | str] = defaultdict(list)
     for key in metadata:
         src_md = copy(item.metadata.get(key))
         if not src_md:
-            print('{0}/metadata/{1} does not exist, skipping.'.format(
-                item.identifier, key), file=sys.stderr)
+            print(f'{item.identifier}/metadata/{key} does not exist, skipping.', file=sys.stderr)
             continue
-        elif key == 'collection' and metadata[key] not in src_md:
-            r = item.remove_from_simplelist(metadata[key], 'holdings')
-            j = r.json()
-            if j.get('success'):
-                print('{} - success: {} no longer in {}'.format(
-                      item.identifier, item.identifier, metadata[key]))
-                sys.exit(0)
-            elif j.get('error', '').startswith('no row to delete for'):
-                print('{} - success: {} no longer in {}'.format(
-                      item.identifier, item.identifier, metadata[key]))
-                sys.exit(0)
-            else:
-                print('{} - error: {}'.format(item.identifier, j.get('error')))
-            sys.exit()
-        elif not isinstance(src_md, list):
+
+        if key == 'collection':
+            _col = copy(metadata[key])
+            _src_md = copy(src_md)
+            if not isinstance(_col, list):
+                _col = [_col]
+            if not isinstance(_src_md, list):
+                _src_md = [_src_md]
+            for c in _col:
+                if c not in _src_md:
+                    r = item.remove_from_simplelist(c, 'holdings')
+                    j = r.json()
+                    if j.get('success'):
+                        print(f'{item.identifier} - success: {item.identifier} no longer in {c}',
+                              file=sys.stderr)
+                        sys.exit(0)
+                    elif j.get('error', '').startswith('no row to delete for'):
+                        print(f'{item.identifier} - success: {item.identifier} no longer in {c}',
+                              file=sys.stderr)
+                        sys.exit(0)
+                    else:
+                        print(f'{item.identifier} - error: {j.get("error")}', file=sys.stderr)
+                        sys.exit(1)
+
+        if not isinstance(src_md, list):
             if key == 'subject':
                 src_md = src_md.split(';')
             elif key == 'collection':
-                print('{} - error: all collections would be removed, '
-                      'not submitting task.'.format(item.identifier), file=sys.stderr)
+                print(f'{item.identifier} - error: all collections would be removed, '
+                      'not submitting task.', file=sys.stderr)
                 sys.exit(1)
 
             if src_md == metadata[key]:
@@ -133,8 +139,12 @@ def remove_metadata(item, metadata, args):
                 continue
 
         for x in src_md:
-            if x not in metadata[key]:
-                md[key].append(x)
+            if isinstance(metadata[key], list):
+                if x not in metadata[key]:
+                    md[key].append(x)  # type: ignore
+            else:
+                if x != metadata[key]:
+                    md[key].append(x)  # type: ignore
 
         if len(md[key]) == len(src_md):
             del md[key]
@@ -145,30 +155,30 @@ def remove_metadata(item, metadata, args):
             md[key] = 'REMOVE_TAG'
 
     if md.get('collection') == []:
-        print('{} - error: all collections would be removed, not submitting task.'.format(
-            item.identifier), file=sys.stderr)
+        print(f'{item.identifier} - error: all collections would be removed, not submitting task.',
+              file=sys.stderr)
         sys.exit(1)
     elif not md:
-        print('{} - warning: nothing needed to be removed.'.format(
-            item.identifier), file=sys.stderr)
+        print(f'{item.identifier} - warning: nothing needed to be removed.', file=sys.stderr)
         sys.exit(0)
 
     r = modify_metadata(item, md, args)
     return r
 
 
-def main(argv, session):
+def main(argv: dict, session: session.ArchiveSession) -> None:
     args = docopt(__doc__, argv=argv)
 
     # Validate args.
     s = Schema({
-        six.text_type: bool,
+        str: bool,
         '<identifier>': list,
         '--modify': list,
         '--header': Or(None, And(Use(get_args_header_dict), dict),
                error='--header must be formatted as --header="key:value"'),
         '--append': list,
         '--append-list': list,
+        '--insert': list,
         '--remove': list,
         '--spreadsheet': Or(None, And(lambda f: os.path.exists(f),
                             error='<file> should be a readable file or directory.')),
@@ -178,11 +188,11 @@ def main(argv, session):
     try:
         args = s.validate(args)
     except SchemaError as exc:
-        print('{0}\n{1}'.format(str(exc), printable_usage(__doc__)), file=sys.stderr)
+        print(f'{exc}\n{printable_usage(__doc__)}', file=sys.stderr)
         sys.exit(1)
 
     formats = set()
-    responses = []
+    responses: list[bool | Response] = []
 
     for i, identifier in enumerate(args['<identifier>']):
         item = session.get_item(identifier)
@@ -191,10 +201,10 @@ def main(argv, session):
         if args['--exists']:
             if item.exists:
                 responses.append(True)
-                print('{0} exists'.format(identifier))
+                print(f'{identifier} exists', file=sys.stderr)
             else:
                 responses.append(False)
-                print('{0} does not exist'.format(identifier), file=sys.stderr)
+                print(f'{identifier} does not exist', file=sys.stderr)
             if (i + 1) == len(args['<identifier>']):
                 if all(r is True for r in responses):
                     sys.exit(0)
@@ -202,14 +212,16 @@ def main(argv, session):
                     sys.exit(1)
 
         # Modify metadata.
-        elif args['--modify'] or args['--append'] or args['--append-list'] \
-                or args['--remove']:
+        elif (args['--modify'] or args['--append'] or args['--append-list']
+              or args['--remove'] or args['--insert']):
             if args['--modify']:
                 metadata_args = args['--modify']
             elif args['--append']:
                 metadata_args = args['--append']
             elif args['--append-list']:
                 metadata_args = args['--append-list']
+            elif args['--insert']:
+                metadata_args = args['--insert']
             if args['--remove']:
                 metadata_args = args['--remove']
             try:
@@ -217,8 +229,9 @@ def main(argv, session):
                 if any('/' in k for k in metadata):
                     metadata = get_args_dict_many_write(metadata)
             except ValueError:
-                print("error: The value of --modify, --remove, --append or --append-list "
-                      "is invalid. It must be formatted as: --modify=key:value",
+                print('error: The value of --modify, --remove, --append, --append-list '
+                      'or --insert is invalid. It must be formatted as: '
+                      '--modify=key:value',
                       file=sys.stderr)
                 sys.exit(1)
 
@@ -227,15 +240,16 @@ def main(argv, session):
             else:
                 responses.append(modify_metadata(item, metadata, args))
             if (i + 1) == len(args['<identifier>']):
-                if all(r.status_code == 200 for r in responses):
+                if all(r.status_code == 200 for r in responses):  # type: ignore
                     sys.exit(0)
                 else:
                     for r in responses:
+                        assert isinstance(r, Response)
                         if r.status_code == 200:
                             continue
                         # We still want to exit 0 if the non-200 is a
                         # "no changes to xml" error.
-                        elif 'no changes' in r.content.decode('utf-8'):
+                        elif 'no changes' in r.text:
                             continue
                         else:
                             sys.exit(1)
@@ -249,14 +263,14 @@ def main(argv, session):
 
         # Dump JSON to stdout.
         else:
-            metadata = json.dumps(item.item_metadata)
-            print(metadata)
+            metadata_str = json.dumps(item.item_metadata)
+            print(metadata_str)
 
     # Edit metadata for items in bulk, using a spreadsheet as input.
     if args['--spreadsheet']:
         if not args['--priority']:
             args['--priority'] = -5
-        with io.open(args['--spreadsheet'], 'rU', newline='', encoding='utf-8') as csvfp:
+        with open(args['--spreadsheet'], newline='', encoding='utf-8') as csvfp:
             spreadsheet = csv.DictReader(csvfp)
             responses = []
             for row in spreadsheet:
@@ -265,18 +279,19 @@ def main(argv, session):
                 item = session.get_item(row['identifier'])
                 if row.get('file'):
                     del row['file']
-                metadata = dict((k.lower(), v) for (k, v) in row.items() if v)
+                metadata = {k.lower(): v for k, v in row.items() if v}
                 responses.append(modify_metadata(item, metadata, args))
 
-            if all(r.status_code == 200 for r in responses):
+            if all(r.status_code == 200 for r in responses):  # type: ignore
                 sys.exit(0)
             else:
                 for r in responses:
+                    assert isinstance(r, Response)
                     if r.status_code == 200:
                         continue
                     # We still want to exit 0 if the non-200 is a
                     # "no changes to xml" error.
-                    elif 'no changes' in r.content.decode('utf-8'):
+                    elif 'no changes' in r.text:
                         continue
                     else:
                         sys.exit(1)
