@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # The internetarchive module is a Python/CLI interface to Archive.org.
 #
@@ -35,32 +34,34 @@ options:
     -n, --num-found                  Print the number of results to stdout.
     -F, --fts                        Beta support for querying the archive.org
                                      full text search API.
+    -D, --dsl-fts                    Sumbit --fts query in dsl [default: False].
     -t, --timeout=<seconds>          Set the timeout in seconds [default: 300].
+
+examples:
+
+    ia search 'collection:nasa' --parameters rows:1
 """
-from __future__ import absolute_import, print_function, unicode_literals
+from __future__ import annotations
+
 import sys
-try:
-    import ujson as json
-except ImportError:
-    import json
 from itertools import chain
 
 from docopt import docopt, printable_usage
-from schema import Schema, SchemaError, Use, Or, And
-import six
-from requests.exceptions import ConnectTimeout
+from requests.exceptions import ConnectTimeout, ReadTimeout
+from schema import And, Or, Schema, SchemaError, Use  # type: ignore[import]
 
-from internetarchive import search_items
+from internetarchive import ArchiveSession, search_items
 from internetarchive.cli.argparser import get_args_dict
 from internetarchive.exceptions import AuthenticationError
+from internetarchive.utils import json
 
 
-def main(argv, session=None):
+def main(argv, session: ArchiveSession | None = None) -> None:
     args = docopt(__doc__, argv=argv)
 
     # Validate args.
     s = Schema({
-        six.text_type: Use(bool),
+        str: Use(bool),
         '<query>': Use(lambda x: ' '.join(x)),
         '--parameters': Use(lambda x: get_args_dict(x, query_string=True)),
         '--header': Or(None, And(Use(get_args_dict), dict),
@@ -73,42 +74,52 @@ def main(argv, session=None):
     try:
         args = s.validate(args)
     except SchemaError as exc:
-        print('{0}\n{1}'.format(str(exc), printable_usage(__doc__)), file=sys.stderr)
+        print(f'{exc}\n{printable_usage(__doc__)}', file=sys.stderr)
         sys.exit(1)
 
     # Support comma separated values.
     fields = list(chain.from_iterable([x.split(',') for x in args['--field']]))
     sorts = list(chain.from_iterable([x.split(',') for x in args['--sort']]))
 
-    r_kwargs = dict(
-        headers=args['--header'],
-        timeout=args['--timeout'],
-    )
+    r_kwargs = {
+        'headers': args['--header'],
+        'timeout': args['--timeout'],
+    }
 
-    search = session.search_items(args['<query>'],
+    search = session.search_items(args['<query>'],  # type: ignore
                                   fields=fields,
                                   sorts=sorts,
                                   params=args['--parameters'],
                                   full_text_search=args['--fts'],
+                                  dsl_fts=args['--dsl-fts'],
                                   request_kwargs=r_kwargs)
 
     try:
         if args['--num-found']:
-            print('{0}'.format(search.num_found))
+            print(search.num_found)
             sys.exit(0)
 
         for result in search:
             if args['--itemlist']:
-                print(result.get('identifier', ''))
+                if args['--fts'] or args['--dsl-fts']:
+                    print('\n'.join(result.get('fields', {}).get('identifier')))
+                else:
+                    print(result.get('identifier', ''))
             else:
                 j = json.dumps(result)
                 print(j)
+                if result.get('error'):
+                    sys.exit(1)
     except ValueError as e:
-        print('error: {0}'.format(e), file=sys.stderr)
+        print(f'error: {e}', file=sys.stderr)
     except ConnectTimeout as exc:
         print('error: Request timed out. Increase the --timeout and try again.',
               file=sys.stderr)
         sys.exit(1)
+    except ReadTimeout as exc:
+        print('error: The server timed out and failed to return all search results,'
+              ' please try again', file=sys.stderr)
+        sys.exit(1)
     except AuthenticationError as exc:
-        print('error: {}'.format(exc), file=sys.stderr)
+        print(f'error: {exc}', file=sys.stderr)
         sys.exit(1)
