@@ -1,8 +1,7 @@
-# -*- coding: utf-8 -*-
 #
 # The internetarchive module is a Python/CLI interface to Archive.org.
 #
-# Copyright (C) 2012-2019 Internet Archive
+# Copyright (C) 2012-2021 Internet Archive
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as
@@ -31,6 +30,7 @@ usage:
     ia tasks <identifier> --cmd=<command> [--comment=<comment>]
                           [--task-args=<k:v>...] [--data=<k:v>...]
                           [--tab-output] [--reduced-priority]
+    ia tasks --get-rate-limit --cmd=<command>
     ia tasks --help
 
 options:
@@ -39,7 +39,7 @@ options:
     -G, --get-task-log=<task_id>  Return the given tasks task log.
     -p, --parameter=<k:v>...      URL parameters passed to catalog.php.
     -c, --cmd=<command>           The task to submit (e.g. make_dark.php).
-    -C, --comment=<command>       A reasonable explantion for why a
+    -C, --comment=<comment>       A reasonable explanation for why a
                                   task is being submitted.
     -T, --tab-output              Output task info in tab-delimited columns.
     -a, --task-args=<k:v>...      Args to submit to the Tasks API.
@@ -47,6 +47,7 @@ options:
                                   Note that it may take a very long time for
                                   your task to run after queued when this setting
                                   is used [default: False].
+    -l, --get-rate-limit          Get rate limit info.
     -d, --data=<k:v>...           Additional data to send when submitting
                                   a task.
 
@@ -60,53 +61,59 @@ examples:
     ia tasks <id> --cmd make_undark.php --comment '<comment>'  # undark item
     ia tasks <id> --cmd make_dark.php --comment '<comment>'  # dark item
     ia tasks <id> --cmd fixer.php --task-args noop:1  # submit a noop fixer.php task
-    ia tasks <id> --cmd fixer.php --task-args 'noop:1;asr:1  # submit multiple fixer ops
+    ia tasks <id> --cmd fixer.php --task-args 'noop:1;asr:1'  # submit multiple fixer ops
+    ia tasks --get-rate-limit --cmd derive.php  # Get rate-limit information for a specific command
 """
-from __future__ import absolute_import, print_function
 import sys
 import warnings
 
 from docopt import docopt
-import six
 
+from internetarchive import ArchiveSession
 from internetarchive.cli.argparser import get_args_dict
+from internetarchive.utils import json
 
 
-def main(argv, session):
+def main(argv, session: ArchiveSession) -> None:
     args = docopt(__doc__, argv=argv)
 
     # Tasks write API.
     if args['--cmd']:
+        if args['--get-rate-limit']:
+            r = session.get_tasks_api_rate_limit(args['--cmd'])
+            print(json.dumps(r))
+            sys.exit(0)
         data = get_args_dict(args['--data'], query_string=True)
         task_args = get_args_dict(args['--task-args'], query_string=True)
         data['args'] = task_args
         r = session.submit_task(args['<identifier>'],
                                 args['--cmd'],
                                 comment=args['--comment'],
-                                priority=data.get('priority'),
+                                priority=int(data.get('priority', 0)),
                                 reduced_priority=args['--reduced-priority'],
                                 data=data)
         j = r.json()
         if j.get('success'):
-            print('success: {}'.format(j.get('value', dict()).get('log')))
+            task_log_url = j.get('value', {}).get('log')
+            print(f'success: {task_log_url}', file=sys.stderr)
+            sys.exit(0)
+        elif 'already queued/running' in j.get('error', ''):
+            print(f'success: {args["--cmd"]} task already queued/running', file=sys.stderr)
             sys.exit(0)
         else:
-            print('error: {}'.format(j.get('error')))
+            print(f'error: {j.get("error")}', file=sys.stderr)
             sys.exit(1)
 
     # Tasks read API.
     params = get_args_dict(args['--parameter'], query_string=True)
     if args['<identifier>']:
-        _params = dict(identifier=args['<identifier>'], catalog=1, history=1)
+        _params = {'identifier': args['<identifier>'], 'catalog': 1, 'history': 1}
         _params.update(params)
         params = _params
     elif args['--get-task-log']:
         log = session.get_task_log(args['--get-task-log'], params)
-        if six.PY2:
-            print(log.encode('utf-8', errors='surrogateescape'))
-        else:
-            print(log.encode('utf-8', errors='surrogateescape')
-                     .decode('utf-8', errors='replace'))
+        print(log.encode('utf-8', errors='surrogateescape')
+                 .decode('utf-8', errors='replace'))
         sys.exit(0)
 
     queryable_params = [
@@ -121,14 +128,14 @@ def main(argv, session):
         'submittime',
     ]
 
-    if not args['<identifier>'] \
-            and not params.get('task_id'):
-        _params = dict(catalog=1, history=0)
+    if not (args['<identifier>']
+            or params.get('task_id')):
+        _params = {'catalog': 1, 'history': 0}
         _params.update(params)
         params = _params
 
     if not any(x in params for x in queryable_params):
-        _params = dict(submitter=session.user_email, catalog=1, history=0, summary=0)
+        _params = {'submitter': session.user_email, 'catalog': 1, 'history': 0, 'summary': 0}
         _params.update(params)
         params = _params
 
@@ -138,21 +145,20 @@ def main(argv, session):
         warnings.warn(warn_msg)
     for t in session.get_tasks(params=params):
         # Legacy support for tab-delimted output.
+        # Mypy is confused by CatalogTask members being created from kwargs
         if args['--tab-output']:
             color = t.color if t.color else 'done'
-            task_args = '\t'.join(['{}={}'.format(k, v) for k, v in t.args.items()])
-            output = '\t'.join([str(x) for x in [
-                t.identifier,
-                t.task_id,
-                t.server,
-                t.submittime,
-                t.cmd,
-                color,
-                t.submitter,
+            task_args = '\t'.join([f'{k}={v}' for k, v in t.args.items()])  # type: ignore
+            output = '\t'.join([str(x) for x in [  # type: ignore
+                t.identifier,  # type: ignore
+                t.task_id,  # type: ignore
+                t.server,  # type: ignore
+                t.submittime,  # type: ignore
+                t.cmd,  # type: ignore
+                color,  # type: ignore
+                t.submitter,  # type: ignore
                 task_args,
             ] if x])
-            print(output)
-            sys.stdout.flush()
+            print(output, flush=True)
         else:
-            print(t.json())
-            sys.stdout.flush()
+            print(t.json(), flush=True)
