@@ -1,10 +1,7 @@
-from __future__ import absolute_import
-
-import json
 import os
 import re
 import sys
-from subprocess import Popen, PIPE
+from subprocess import PIPE, Popen
 
 import pytest
 import responses
@@ -13,6 +10,7 @@ from responses import RequestsMock
 from internetarchive import get_session
 from internetarchive.api import get_item
 from internetarchive.cli import ia
+from internetarchive.utils import json
 
 try:
     FileNotFoundError
@@ -27,11 +25,11 @@ except NameError:
 
 PROTOCOL = 'https:'
 BASE_URL = 'https://archive.org/'
-METADATA_URL = BASE_URL + 'metadata/'
+METADATA_URL = f'{BASE_URL}metadata/'
 ROOT_DIR = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
 TEST_CONFIG = os.path.join(ROOT_DIR, 'tests/ia.ini')
 NASA_METADATA_PATH = os.path.join(ROOT_DIR, 'tests/data/metadata/nasa.json')
-NASA_EXPECTED_FILES = set([
+NASA_EXPECTED_FILES = {
     'globe_west_540.jpg',
     'globe_west_540_thumb.jpg',
     'nasa_archive.torrent',
@@ -42,7 +40,7 @@ NASA_EXPECTED_FILES = set([
     'nasa_itemimage.jpg',
     'globe_west_540_thumb.jpg',
     '__ia_thumb.jpg',
-])
+}
 
 
 def ia_call(argv, expected_exit_code=0):
@@ -58,16 +56,16 @@ def ia_call(argv, expected_exit_code=0):
 
 
 def files_downloaded(path):
-    found_files = set([])
+    found_files = set()
     try:
         found_files = set(os.listdir(path))
-    except (FileNotFoundError, WindowsError, OSError):
+    except OSError:
         pass
     return found_files
 
 
 def load_file(filename):
-    with open(filename, 'r') as fh:
+    with open(filename) as fh:
         return fh.read()
 
 
@@ -89,14 +87,16 @@ def call_cmd(cmd, expected_exit_code=0):
 
 class IaRequestsMock(RequestsMock):
     def add_metadata_mock(self, identifier, body=None, method=responses.GET,
-                          protocol='https?'):
-        url = re.compile(r'%s://archive.org/metadata/%s' % (protocol, identifier))
+                          protocol='https?', transform_body=None):
+        url = re.compile(f'{protocol}://archive.org/metadata/{identifier}')
         if body is None:
-            body = load_test_data_file('metadata/' + identifier + '.json')
+            body = load_test_data_file(f'metadata/{identifier}.json')
+        if transform_body:
+            body = transform_body(body)
         self.add(method, url, body=body, content_type='application/json')
 
     def mock_all_downloads(self, num_calls=1, body='test content', protocol='https?'):
-        url = re.compile(r'{0}://archive.org/download/.*'.format(protocol))
+        url = re.compile(f'{protocol}://archive.org/download/.*')
         for _ in range(6):
             self.add(responses.GET, url, body=body)
 
@@ -124,7 +124,7 @@ def nasa_item():
 
 @pytest.fixture
 def session():
-    return get_session(config=dict(s3=dict(access='access', secret='secret')))
+    return get_session(config={'s3': {'access': 'access', 'secret': 'secret'}})
 
 
 @pytest.fixture
@@ -132,6 +132,7 @@ def nasa_metadata():
     return json.loads(load_test_data_file('metadata/nasa.json'))
 
 
-@pytest.fixture
+# TODO: Why is this function defined twice in this file?  See issue #505
+@pytest.fixture  # type: ignore
 def nasa_item(nasa_mocker):
     return get_item('nasa')
