@@ -5,4 +5,4 @@ def test_AuthenticationError():
     try:
         raise internetarchive.exceptions.AuthenticationError('Authentication Failed')
     except Exception as exc:
-        assert str(exc) == """Authentication Failed"""
+        assert str(exc) == 'Authentication Failed'
